@@ -22,7 +22,7 @@ class ValidateRule:
         if self._alias.get(alias) is None:
             self._alias[alias] = alias
         else:
-            raise ValidateRuleException(f"El alias '{alias}' esta duplicado")
+            raise ValidateRuleException(f"The {alias} alias is duplicated in the rule")
 
     def validate_alias_error_steps(self, settings):
         ''' Receive settings if the key exists error_steps will iterate the steps '''
